#========================================================================================
# package      DE_EPAGES::Amazon::Hooks::ProductPortal
# state        public
# description  Runs When Product Portal Hooks are triggered. 
#========================================================================================
package DE_EPAGES::Amazon::Hooks::ProductPortal;

use strict;
use DE_EPAGES::Object::API::Factory qw (LoadClassByAlias);

#========================================================================================
# function     OnDeletePortalConfig
# state        public
#----------------------------------------------------------------------------------------
# syntax       OnDeletePortalConfig( $hParams );
#----------------------------------------------------------------------------------------
# description  OnDeletePortalConfig is triggered when a portal config is removed.
#----------------------------------------------------------------------------------------
# input        $hParams | hook arguments, used keys are
#               <ul>
#                   <li>Object
#               </ul> | ref.hash.*
#========================================================================================
sub OnDeletePortalConfig {
    my ($hParams) = @_;
    my $PortalConfig   = $hParams->{'Object'};
    
    my $children = $PortalConfig->folder('AmazonOffers')->children;
    
    foreach my $Offer (@$children) {
        $Offer->delete if ($Offer);
    }
    # Delete messages in AmazonSubmitFeedQueue
    LoadClassByAlias('AmazonSubmitFeedQueue')->deleteObjects( 'ByPortalConfigID', [ $PortalConfig->id ] );

    # we do the following actions only for unity shops
    my $Shop = $PortalConfig->getSite();
    _DeleteAmazonAuthNotification($Shop, $PortalConfig) if $Shop->get('IsUnityRegistered');
}

#========================================================================================
# function     _DeleteAmazonAuthNotification
# state        private
#----------------------------------------------------------------------------------------
# syntax       _DeleteAmazonAuthNotification( $Shop );
#----------------------------------------------------------------------------------------
# description  deletes the amazon auth notification for a given Shop
#----------------------------------------------------------------------------------------
# input        $Shop | shop object | object
# input        $PortalConfig | portalconfig object | object
#========================================================================================
sub _DeleteAmazonAuthNotification {
    my ($Shop, $PortalConfig) = @_;

    if ($Shop->folder('ShopNotifications')->existsChild('AmazonAuthExpire')) {
        # delete the notification for AmazonAuthExpire
        my $AmazonAuthExpireNotification = $Shop->folder('ShopNotifications')->child('AmazonAuthExpire');
        $AmazonAuthExpireNotification->deleteObject($PortalConfig);
    }

    return;
}
1;