#========================================================================================
# package      DE_EPAGES::Coupon::DAL::Coupon
# state        private
# description  database interface for tables:
#               <ul>
#                   <li>couponcampaign
#                   <li>couponcode
#                   <li>couponcondition
#               </ul>
#========================================================================================
package DE_EPAGES::Coupon::DAL::Coupon;
use base qw (Exporter);

use strict;

our @EXPORT_OK = qw (
    DAL_GetCouponCodesCountByCouponCampaignID
    DAL_GetCouponCodesRedeemCountByCouponCampaignID
    DAL_GetCouponConditionsByCouponCampaignID
);

use DE_EPAGES::Core::API::Log qw ( GetLog );
use DE_EPAGES::Core::API::PerlTools qw ( UsePackage );
use DE_EPAGES::Database::API::Connection qw (  GetCurrentDBHandle );

sub _CallDriver {
    my ($FunctionName, @Parameter) = @_;
    my $dbi = GetCurrentDBHandle();
    my $Package = 'DE_EPAGES::Coupon::DAL::'.$dbi->driverName.'::Coupon';
    UsePackage($Package);
    GetLog->debug("call $Package->$FunctionName()");
    return $Package->$FunctionName($dbi, @Parameter);
}

#========================================================================================
# function     DAL_GetCouponCodesCountByCouponCampaignID
#----------------------------------------------------------------------------------------
# syntax       $count = DAL_GetCouponCodesCountByCouponCampaignID($CouponCampaignID);
#----------------------------------------------------------------------------------------
# description  count all coupon codes for a campaign
#----------------------------------------------------------------------------------------
# input        $CouponCampaignID | coupon campaign id | int
# return       $count | number of couponcodes | int
#========================================================================================
sub DAL_GetCouponCodesCountByCouponCampaignID {
    my ($CouponCampaignID) = @_;
    return _CallDriver('GetCouponCodesCountByCouponCampaignID', $CouponCampaignID);
}

#========================================================================================
# function     DAL_GetCouponCodesRedeemCountByCouponCampaignID
#----------------------------------------------------------------------------------------
# syntax       $redeemcount = DAL_GetCouponCodesRedeemCountByCouponCampaignID($CouponCampaignID);
#----------------------------------------------------------------------------------------
# description  add the redeem counts of all coupon codes for a campaign
#----------------------------------------------------------------------------------------
# input        $CouponCampaignID | coupon campaign id | int
# return       $count | sum of couponcodes redeemcounts | int
#========================================================================================
sub DAL_GetCouponCodesRedeemCountByCouponCampaignID {
    my ($CouponCampaignID) = @_;
    return _CallDriver('GetCouponCodesRedeemCountByCouponCampaignID', $CouponCampaignID);
}

#========================================================================================
# function     DAL_GetCouponConditionsByCouponCampaignID
#----------------------------------------------------------------------------------------
# syntax       $TotalOrdersCount = DAL_GetCouponConditionsByCouponCampaignID($CouponCampaignID);
#----------------------------------------------------------------------------------------
# description  Gets all coupon conditions for a campaign
#----------------------------------------------------------------------------------------
# input        $CouponCampaignID | coupon campaign object id | integer
# return       $ahConditions | columns (conditionobjectid, type) of all matching coupon conditions | ref.array.hash
#========================================================================================
sub DAL_GetCouponConditionsByCouponCampaignID ($) {
    my ($CouponCampaignID) = @_;
    return _CallDriver('GetCouponConditionsByCouponCampaignID', $CouponCampaignID);
}

1;
