#========================================================================================
# package      DE_EPAGES::Coupon::DAL::SQL::Coupon
# state        private
# description  Generic SQL database interface for tables:
#               <ul>
#                   <li>couponcampaign
#                   <li>couponcode
#                   <li>couponcondition
#               </ul>
#========================================================================================
package DE_EPAGES::Coupon::DAL::SQL::Coupon;

use strict;

#========================================================================================
# function     GetCouponCodesCountByCouponCampaignID
#----------------------------------------------------------------------------------------
# syntax       $count = $Package->GetCouponCodesCountByCouponCampaignID($dbh, $CouponCampaignID);
#----------------------------------------------------------------------------------------
# description  count all coupon codes for a campaign
#----------------------------------------------------------------------------------------
# input        $dbh | database handle | object
# input        $CouponCampaignID | coupon campaign id | int
# return       $count | number of couponcodes | int
#========================================================================================
sub GetCouponCodesCountByCouponCampaignID {
    my $self = shift;
    my $dbi = shift;
    my ($CouponCampaignID) = @_;
    my (@WhereClauses, @Parameter);
    unshift @WhereClauses, 'couponcampaignid = ?';
    unshift @Parameter, $CouponCampaignID;

    my $sql = 'SELECT count(couponcodeid) from couponcode WHERE ' . join(' AND ', @WhereClauses);
    my $dbResult = $dbi->execute($sql, \@Parameter, ['Integer']);

    return $dbResult->[0]->[0];
}

#========================================================================================
# function     GetCouponCodesRedeemCountByCouponCampaignID
#----------------------------------------------------------------------------------------
# syntax       $count = $Package->GetCouponCodesRedeemCountByCouponCampaignID($dbh, $CouponCampaignID);
#----------------------------------------------------------------------------------------
# description  add the redeem counts of all coupon codes for a campaign
#----------------------------------------------------------------------------------------
# input        $dbh | database handle | object
# input        $CouponCampaignID | coupon campaign id | int
# return       $count | sum of couponcodes redeemcounts | int
#========================================================================================
sub GetCouponCodesRedeemCountByCouponCampaignID {
    my $self = shift;
    my $dbi = shift;
    my ($CouponCampaignID) = @_;
    my (@WhereClauses, @Parameter);
    unshift @WhereClauses, 'couponcampaignid = ?';
    unshift @Parameter, $CouponCampaignID;

    my $sql = 'SELECT sum(redeemcount) from couponcode WHERE ' . join(' AND ', @WhereClauses);
    my $dbResult = $dbi->execute($sql, \@Parameter, ['Integer']);

    return $dbResult->[0]->[0];
}

#========================================================================================
# function     GetCouponConditionsByCouponCampaignID
#----------------------------------------------------------------------------------------
# syntax       $ahConditions = $Package->GetCouponConditionsByCouponCampaignID($dbi, $CouponCampaignID);
#----------------------------------------------------------------------------------------
# description  Returns all coupon conditions for a campaign
#----------------------------------------------------------------------------------------
# input        $dbh | database handle | object
# input        $CouponCampaignID | coupon campaign id | integer
# return       $ahConditions | columns (conditionobjectid, type) of all matching coupon conditions | ref.array.hash
#========================================================================================
sub GetCouponConditionsByCouponCampaignID {
    my $self = shift;
    my $dbi = shift;
    my $CouponCampaignID = shift;

    my $sql = <<END_SQL;
SELECT conditionobjectid, type from couponcondition WHERE couponcampaignid = ?
END_SQL

    my $dbResult = $dbi->execute($sql, [$CouponCampaignID], ['integer', 'string']);

    return $dbResult;
}

1;
